@@ -11,6 +11,7 @@ from gitignore_parser import parse_gitignore
 end_terminators = {
     'slash': '// inserted by copyright_tool',
     'hash': '## inserted by copyright_tool'
+    'html': '<! inserted by copyright_tool -->'
 }
 
 language_support = {
@@ -26,6 +27,11 @@ language_support = {
     'sh': 'hash',
     'java': 'slash',
     'tf': 'slash',
+    'yaml': 'hash',
+    'yml': 'hash',
+    'html': 'html',
+    'mdx': 'html',
+    'css': 'slash',
 }
 
 file_support = {
